<?php

/**
 * Returns HTML for the Contextly widget wrapper.
 *
 * @param object|null $node
 */
function theme_contextly_widget($node) {
  if (empty($node->nid)) {
    return '';
  }

  // Export settings.
  $settings = Contextly::getInstance()
    ->buildWidgetsSettings($node);
  _contextly_add_js_setting_once('widget', $settings);

  // Include JS and report to user if it fails.
  $library_included = _contextly_add_library('widget');
  if (!$library_included && user_access('administer contextly')) {
    $error_message = t('The Contextly widget is not able to load because of missing libraries. See log for details.');
    drupal_set_message($error_message, 'status', FALSE);
  }

  // Build the widget wrapper.
  $attributes = array(
    'class' => 'contextly-placeholder contextly-snippet-placeholder',
  );
  $output = '<div' . drupal_attributes($attributes) . '></div>';

  return $output;
}

function template_preprocess_contextly_overlay(&$vars) {
  // Get head content.
  $vars['head'] = drupal_get_html_head();

  // Styles for the overlay are added with the "overlay" media. We get them
  // non-rendered, move to the "all" media and then render.
  $css = drupal_add_css();
  if (!empty($css['overlay'])) {
    $css = array(
      'all' => $css['overlay'],
    );
    $vars['styles'] = drupal_get_css($css);
  }
  else {
    $vars['styles'] = '';
  }

  // Scripts for the overlay are added to the "overlay" scope. Use them only.
  $vars['scripts'] = drupal_get_js('overlay');

  // Language.
  $vars['language'] = $GLOBALS['language'];
}

function template_preprocess_contextly_editor(&$vars) {
  $vars['alert'] = theme('contextly_editor_alert');
  $vars['input_fields'] = theme('contextly_editor_input_fields', $vars['editor_type']);
  $vars['search_results'] = theme('contextly_editor_search_results', $vars['editor_type']);
  $vars['url_preview'] = theme('contextly_editor_url_preview', $vars['editor_type']);
}
